@@ -130,11 +130,11 @@ match_cipher (const char *cipher,
 
 gboolean
 nm_setting_wireless_ap_security_compatible (NMSettingWireless *s_wireless,
-								    NMSettingWirelessSecurity *s_wireless_sec,
-								    guint32 ap_flags,
-								    guint32 ap_wpa,
-								    guint32 ap_rsn,
-								    guint32 ap_mode)
+                                            NMSettingWirelessSecurity *s_wireless_sec,
+                                            NM80211ApFlags ap_flags,
+                                            NM80211ApSecurityFlags ap_wpa,
+                                            NM80211ApSecurityFlags ap_rsn,
+                                            NM80211Mode ap_mode)
 {
 	NMSettingWirelessPrivate *priv;
 	const char *key_mgmt = NULL, *cipher;
